# 'Polemarch' documentation

# API

Polemarch provides REST API for all it’s functionality accessible via web GUI, because our GUI also uses this API to work. Below there is an information about every entity we have in Polemarch and methods applicable to it.

This is an example of api schema, but you can find actual schema on Polemarch host at `/api/v2/openapi/`.

## Structure

In Polemarch we have some entities that can be nested to another entities. Below examples of such entites:

Inventory can be nested into Project

Group can be nested into Inventory or into another Group with `children=true`

Host can be nested into Inventory or into another Group with `children=false`

User can be nested into Team

For add entities into another, you only need send `[{"id": [instance_id]}, ...]` to subpath. Also you can insert instead of data results of bulk request, inner mechanism add all entities in result to parent entity.

### API Paths

`GET` `/community_template/`

  List of community project templates.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "example type",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/community_template/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (ProjectTemplate Schema)

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/community_template/{id}/`

  Return a community project template instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "description": "example description",
          "repository": "example repository",
          "name": "example name",
          "type": "example type",
          "id": 1
      }

  JSON Parameters

    - repository (string) – Repository(maxLength=2048, minLength=1)

    - name (string) – Name(maxLength=1024, minLength=1)

    - type (string) – Type(enum=[‘GIT’, ‘TAR’])

    - id (integer) – Id

    - description (string) – Description(minLength=1)

param integer id(required)

  A unique value identifying this project template.

`POST` `/community_template/{id}/use_it/`

  Create project based on this template.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "project_id": 1
      }

  JSON Parameters

    - name (string) – Name(minLength=1)

    - project_id (integer) – Project id(readOnly=True, additionalProperties=OrderedDict([(‘redirect’, True)]), x-nullable=True)

param integer id(required)

  > A unique value identifying this project template.

  query schema data(required)

    ProjectTemplateCreate Schema

`GET` `/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "children": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/group/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Group Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Contains groups(default=False)

  Query Parameters

    - data(required) (schema) – GroupCreateMaster Schema

`GET` `/group/{id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer id(required)

  A unique integer value identifying this group.

`PUT` `/group/{id}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    OneGroup Schema

`PATCH` `/group/{id}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    OneGroup Schema

`DELETE` `/group/{id}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this group.

`POST` `/group/{id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "children": true,
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    Group Schema

`GET` `/group/{id}/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "children": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/group/1/group/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Group Schema)

param integer id(required)

  A unique integer value identifying this group.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/group/{id}/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Contains groups(default=False)

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    GroupCreateMaster Schema

`GET` `/group/{id}/group/{group_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this group.

`PUT` `/group/{id}/group/{group_id}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    OneGroup Schema

`PATCH` `/group/{id}/group/{group_id}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    OneGroup Schema

`DELETE` `/group/{id}/group/{group_id}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this group.

`POST` `/group/{id}/group/{group_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "children": true,
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    Group Schema

`POST` `/group/{id}/group/{group_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    SetOwner Schema

`GET` `/group/{id}/group/{group_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/group/1/group/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this group.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/group/{id}/group/{group_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    InventoryVariable Schema

`GET` `/group/{id}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/group/{id}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/group/{id}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/group/{id}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/group/{id}/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "HOST",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/group/1/host/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Host Schema)

param integer id(required)

  A unique integer value identifying this group.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string type

  Instance type.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/group/{id}/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    OneHost Schema

`GET` `/group/{id}/host/{host_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this group.

`PUT` `/group/{id}/host/{host_id}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    OneHost Schema

`PATCH` `/group/{id}/host/{host_id}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    OneHost Schema

`DELETE` `/group/{id}/host/{host_id}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this group.

`POST` `/group/{id}/host/{host_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

    - id (integer) – Id(readOnly=True)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    Host Schema

`POST` `/group/{id}/host/{host_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    SetOwner Schema

`GET` `/group/{id}/host/{host_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/group/1/host/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this group.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/group/{id}/host/{host_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    InventoryVariable Schema

`GET` `/group/{id}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/group/{id}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/group/{id}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/group/{id}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`POST` `/group/{id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    SetOwner Schema

`GET` `/group/{id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/group/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer id(required)

  A unique integer value identifying this group.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/group/{id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  > A unique integer value identifying this group.

  query schema data(required)

    InventoryVariable Schema

`GET` `/group/{id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/group/{id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/group/{id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/group/{id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this group.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/history/`

  Return all history of executions.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "executor": 1,
                  "options": "example options",
                  "mode": "example mode",
                  "project": 1,
                  "status": "example status",
                  "id": 1,
                  "initiator": 1,
                  "initiator_type": "example initiator_type",
                  "start_time": "2019-01-07T06:10:31+10:00",
                  "kind": "example kind",
                  "stop_time": "2019-01-07T06:10:31+10:00",
                  "inventory": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/history/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (History Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string mode

  Module or playbook name.

query string kind

  Kind of execution.

query string status

  Status of execution.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string name

  A name string value (or comma separated list) of instance.

query string older

  Older then this time

query string newer

  Newer then this time

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/history/{id}/`

  Return a execution history instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "raw_inventory": "example raw_inventory",
          "executor": 1,
          "options": "example options",
          "mode": "example mode",
          "execute_args": "example execute_args",
          "execution_time": "22:11:34",
          "project": 1,
          "status": "example status",
          "stop_time": "2019-01-07T06:10:31+10:00",
          "id": 1,
          "initiator": 1,
          "raw_stdout": "example raw_stdout",
          "initiator_type": "example initiator_type",
          "start_time": "2019-01-07T06:10:31+10:00",
          "raw_args": "example raw_args",
          "kind": "example kind",
          "revision": "example revision",
          "inventory": 1
      }

  JSON Parameters

    - project (integer) – Project(x-nullable=True)

    - initiator_type (string) – Initiator type(maxLength=50, minLength=1)

    - kind (string) – Kind(maxLength=50, minLength=1)

    - initiator (integer) – Initiator

    - raw_args (string) – Raw args(minLength=1)

    - revision (string) – Revision(maxLength=256, x-nullable=True)

    - stop_time (date-time) – Stop time(x-nullable=True)

    - start_time (date-time) – Start time

    - raw_stdout (string) – Raw stdout(readOnly=True)

    - raw_inventory (string) – Raw inventory(minLength=1)

    - executor (integer) – Executor(x-nullable=True)

    - status (string) – Status(enum=[‘DELAY’, ‘RUN’, ‘OK’, ‘ERROR’, ‘OFFLINE’, ‘INTERRUPTED’])

    - id (integer) – Id(readOnly=True)

    - execution_time (uptime) – Execution time

    - mode (string) – Mode(maxLength=256, minLength=1)

    - inventory (integer) – Inventory(x-nullable=True)

    - execute_args (string) – Execute args(readOnly=True)

    - options (string) – Options(readOnly=True)

param integer id(required)

  A unique integer value identifying this history.

`DELETE` `/history/{id}/`

  Remove an existing history record.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this history.

`POST` `/history/{id}/cancel/`

  Cencel working task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail"
      }

  JSON Parameters

    - detail (string) – Detail(minLength=1)

param integer id(required)

  > A unique integer value identifying this history.

  query schema data(required)

    Empty Schema

`DELETE` `/history/{id}/clear/`

  Clear history output.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this history.

`GET` `/history/{id}/facts/`

  Get compilated history facts (only for execution ‘module’ with module ‘setup’).

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this history.

`GET` `/hook/`

  Return all hooks.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "recipients": "example recipients",
                  "when": "example when",
                  "enable": true,
                  "name": "example name",
                  "id": 1,
                  "type": "example type"
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/hook/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Hook Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string type

  Instance type.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/hook/`

  Create a new hook.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "recipients": "example recipients",
          "when": "example when",
          "enable": true,
          "name": "example name",
          "id": 1,
          "type": "example type"
      }

  JSON Parameters

    - when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’])

    - enable (boolean) – Enable

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - recipients (string) – Recipients(minLength=1)

    - type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’])

  Query Parameters

    - data(required) (schema) – Hook Schema

`GET` `/hook/{id}/`

  Return a hook instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "recipients": "example recipients",
          "when": "example when",
          "enable": true,
          "name": "example name",
          "id": 1,
          "type": "example type"
      }

  JSON Parameters

    - when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’])

    - enable (boolean) – Enable

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - recipients (string) – Recipients(minLength=1)

    - type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’])

param integer id(required)

  A unique integer value identifying this hook.

`PUT` `/hook/{id}/`

  Update a hook.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "recipients": "example recipients",
          "when": "example when",
          "enable": true,
          "name": "example name",
          "id": 1,
          "type": "example type"
      }

  JSON Parameters

    - when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’])

    - enable (boolean) – Enable

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - recipients (string) – Recipients(minLength=1)

    - type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’])

param integer id(required)

  > A unique integer value identifying this hook.

  query schema data(required)

    Hook Schema

`PATCH` `/hook/{id}/`

  Update one or more fields on an existing hook.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "recipients": "example recipients",
          "when": "example when",
          "enable": true,
          "name": "example name",
          "id": 1,
          "type": "example type"
      }

  JSON Parameters

    - when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’])

    - enable (boolean) – Enable

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - recipients (string) – Recipients(minLength=1)

    - type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’])

param integer id(required)

  > A unique integer value identifying this hook.

  query schema data(required)

    Hook Schema

`DELETE` `/hook/{id}/`

  Remove an existing hook.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this hook.

`GET` `/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "HOST",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/host/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Host Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string type

  Instance type.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

  Query Parameters

    - data(required) (schema) – OneHost Schema

`GET` `/host/{id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer id(required)

  A unique integer value identifying this host.

`PUT` `/host/{id}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer id(required)

  > A unique integer value identifying this host.

  query schema data(required)

    OneHost Schema

`PATCH` `/host/{id}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer id(required)

  > A unique integer value identifying this host.

  query schema data(required)

    OneHost Schema

`DELETE` `/host/{id}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this host.

`POST` `/host/{id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  > A unique integer value identifying this host.

  query schema data(required)

    Host Schema

`POST` `/host/{id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer id(required)

  > A unique integer value identifying this host.

  query schema data(required)

    SetOwner Schema

`GET` `/host/{id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/host/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer id(required)

  A unique integer value identifying this host.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/host/{id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  > A unique integer value identifying this host.

  query schema data(required)

    InventoryVariable Schema

`GET` `/host/{id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this host.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/host/{id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this host.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/host/{id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this host.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/host/{id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this host.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/inventory/`

  Return all inventories.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Inventory Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/inventory/`

  Create a new inventory.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

  Query Parameters

    - data(required) (schema) – OneInventory Schema

`POST` `/inventory/import_inventory/`

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "raw_data": "example raw_data",
          "inventory_id": 1
      }

  JSON Parameters

    - inventory_id (integer) – Inventory id(additionalProperties=OrderedDict([(‘redirect’, True)]), x-nullable=True)

    - raw_data (string) – Raw data(minLength=1)

    - name (string) – Name(minLength=1)

  Query Parameters

    - data(required) (schema) – InventoryImport Schema

`GET` `/inventory/{id}/`

  Return a inventory instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this inventory.

`PUT` `/inventory/{id}/`

  Update a inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    OneInventory Schema

`PATCH` `/inventory/{id}/`

  Update one or more fields on an existing inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    OneInventory Schema

`DELETE` `/inventory/{id}/`

  Remove an existing inventory.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this inventory.

`GET` `/inventory/{id}/all_groups/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "children": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/1/all_groups/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Group Schema)

param integer id(required)

  A unique integer value identifying this inventory.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/inventory/{id}/all_groups/{all_groups_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param string all_groups_id(required)

param integer id(required)

  A unique integer value identifying this inventory.

`GET` `/inventory/{id}/all_hosts/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "HOST",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/1/all_hosts/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Host Schema)

param integer id(required)

  A unique integer value identifying this inventory.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string type

  Instance type.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/inventory/{id}/all_hosts/{all_hosts_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param string all_hosts_id(required)

param integer id(required)

  A unique integer value identifying this inventory.

`POST` `/inventory/{id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    Inventory Schema

`GET` `/inventory/{id}/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "children": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/1/group/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Group Schema)

param integer id(required)

  A unique integer value identifying this inventory.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/inventory/{id}/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Contains groups(default=False)

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    GroupCreateMaster Schema

`GET` `/inventory/{id}/group/{group_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this inventory.

`PUT` `/inventory/{id}/group/{group_id}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    OneGroup Schema

`PATCH` `/inventory/{id}/group/{group_id}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    OneGroup Schema

`DELETE` `/inventory/{id}/group/{group_id}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this inventory.

`POST` `/inventory/{id}/group/{group_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "children": true,
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    Group Schema

`POST` `/inventory/{id}/group/{group_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    SetOwner Schema

`GET` `/inventory/{id}/group/{group_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/1/group/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this inventory.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/inventory/{id}/group/{group_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    InventoryVariable Schema

`GET` `/inventory/{id}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/inventory/{id}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/inventory/{id}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/inventory/{id}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required)

  A unique integer value identifying instance of this groups sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/inventory/{id}/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "HOST",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/1/host/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Host Schema)

param integer id(required)

  A unique integer value identifying this inventory.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string type

  Instance type.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/inventory/{id}/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    OneHost Schema

`GET` `/inventory/{id}/host/{host_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this inventory.

`PUT` `/inventory/{id}/host/{host_id}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    OneHost Schema

`PATCH` `/inventory/{id}/host/{host_id}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    OneHost Schema

`DELETE` `/inventory/{id}/host/{host_id}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this inventory.

`POST` `/inventory/{id}/host/{host_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

    - id (integer) – Id(readOnly=True)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    Host Schema

`POST` `/inventory/{id}/host/{host_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    SetOwner Schema

`GET` `/inventory/{id}/host/{host_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/1/host/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this inventory.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/inventory/{id}/host/{host_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    InventoryVariable Schema

`GET` `/inventory/{id}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/inventory/{id}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/inventory/{id}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/inventory/{id}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required)

  A unique integer value identifying instance of this hosts sublist.

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`POST` `/inventory/{id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    SetOwner Schema

`GET` `/inventory/{id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/inventory/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer id(required)

  A unique integer value identifying this inventory.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/inventory/{id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  > A unique integer value identifying this inventory.

  query schema data(required)

    InventoryVariable Schema

`GET` `/inventory/{id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/inventory/{id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/inventory/{id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/inventory/{id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this inventory.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/project/`

  Return all projects.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "example type",
                  "status": "example status",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Project Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string status

  Project sync status.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string status__not

  Project sync status.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/`

  Create a new project.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "repo_auth": "NONE",
          "auth_data": "test_dynamic",
          "repository": "MANUAL",
          "status": "example status",
          "id": 1,
          "branch": "test_dynamic",
          "name": "example name",
          "type": "MANUAL"
      }

  JSON Parameters

    - branch (dynamic) – Branch for GIT(branch/tag/SHA) or TAR(subdir)

    - status (string) – Status(readOnly=True, minLength=1)

    - type (string) – Repo type(enum=[‘MANUAL’, ‘GIT’, ‘TAR’], default=MANUAL)

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - repo_auth (dynamic) – Repo auth type

    - auth_data (dynamic) – Repo auth data

    - repository (string) – Repo url(default=MANUAL, minLength=1)

  Query Parameters

    - data(required) (schema) – ProjectCreateMaster Schema

`GET` `/project/{id}/`

  Return a project instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "repository": "MANUAL",
          "status": "example status",
          "revision": "example revision",
          "notes": "example\ntext\narea\n",
          "id": 1,
          "branch": "example branch",
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "readme_content": "test_html",
          "execute_view_data": {}
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - status (string) – Status(enum=[‘NEW’, ‘ERROR’, ‘OK’, ‘WAIT_SYNC’, ‘SYNC’], readOnly=True)

    - repository (string) – Repository(default=MANUAL, minLength=1)

    - execute_view_data (object) – (Data Schema)

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - readme_content (html) – Information(readOnly=True)

    - revision (string) – Revision(readOnly=True)

    - branch (string) – Branch(readOnly=True)

    - notes (textarea) – Notes

param integer id(required)

  A unique integer value identifying this project.

`PUT` `/project/{id}/`

  Update a project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "repository": "MANUAL",
          "status": "example status",
          "revision": "example revision",
          "notes": "example\ntext\narea\n",
          "id": 1,
          "branch": "example branch",
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "readme_content": "test_html",
          "execute_view_data": {}
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - status (string) – Status(enum=[‘NEW’, ‘ERROR’, ‘OK’, ‘WAIT_SYNC’, ‘SYNC’], readOnly=True)

    - repository (string) – Repository(default=MANUAL, minLength=1)

    - execute_view_data (object) – (Data Schema)

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - readme_content (html) – Information(readOnly=True)

    - revision (string) – Revision(readOnly=True)

    - branch (string) – Branch(readOnly=True)

    - notes (textarea) – Notes

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    OneProject Schema

`PATCH` `/project/{id}/`

  Update one or more fields on an existing project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "repository": "MANUAL",
          "status": "example status",
          "revision": "example revision",
          "notes": "example\ntext\narea\n",
          "id": 1,
          "branch": "example branch",
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "readme_content": "test_html",
          "execute_view_data": {}
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - status (string) – Status(enum=[‘NEW’, ‘ERROR’, ‘OK’, ‘WAIT_SYNC’, ‘SYNC’], readOnly=True)

    - repository (string) – Repository(default=MANUAL, minLength=1)

    - execute_view_data (object) – (Data Schema)

    - id (integer) – Id(readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - readme_content (html) – Information(readOnly=True)

    - revision (string) – Revision(readOnly=True)

    - branch (string) – Branch(readOnly=True)

    - notes (textarea) – Notes

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    OneProject Schema

`DELETE` `/project/{id}/`

  Remove an existing project.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this project.

`POST` `/project/{id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "example type",
          "status": "example status",
          "id": 1
      }

  JSON Parameters

    - status (string) – Status(enum=[‘NEW’, ‘ERROR’, ‘OK’, ‘WAIT_SYNC’, ‘SYNC’], readOnly=True)

    - name (string) – Name(maxLength=512, minLength=1)

    - type (string) – Type(readOnly=True, minLength=1)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    Project Schema

`POST` `/project/{id}/execute_module/`

  Execute ansible -m [module] with arguments.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "history_id": 1,
          "executor": 1
      }

  JSON Parameters

    - executor (integer) – Executor(x-nullable=True)

    - history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)]), x-nullable=True)

    - detail (string) – Detail(minLength=1)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    AnsibleModule Schema

`POST` `/project/{id}/execute_playbook/`

  Execute ansible-playbook with arguments.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "history_id": 1,
          "executor": 1
      }

  JSON Parameters

    - executor (integer) – Executor(x-nullable=True)

    - history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)]), x-nullable=True)

    - detail (string) – Detail(minLength=1)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    AnsiblePlaybook Schema

`GET` `/project/{id}/history/`

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "inventory": 1,
                  "options": "example options",
                  "mode": "example mode",
                  "status": "example status",
                  "stop_time": "2019-01-07T06:10:31+10:00",
                  "id": 1,
                  "initiator": 1,
                  "initiator_type": "example initiator_type",
                  "start_time": "2019-01-07T06:10:31+10:00",
                  "kind": "example kind",
                  "revision": "example revision",
                  "executor": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/history/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (ProjectHistory Schema)

param integer id(required)

  A unique integer value identifying this project.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string mode

  Module or playbook name.

query string kind

  Kind of execution.

query string status

  Status of execution.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string name

  A name string value (or comma separated list) of instance.

query string older

  Older then this time

query string newer

  Newer then this time

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/project/{id}/history/{history_id}/`

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "raw_inventory": "example raw_inventory",
          "executor": 1,
          "options": "example options",
          "mode": "example mode",
          "execute_args": "example execute_args",
          "execution_time": "22:11:34",
          "project": 1,
          "status": "example status",
          "stop_time": "2019-01-07T06:10:31+10:00",
          "id": 1,
          "initiator": 1,
          "raw_stdout": "example raw_stdout",
          "initiator_type": "example initiator_type",
          "start_time": "2019-01-07T06:10:31+10:00",
          "raw_args": "example raw_args",
          "kind": "example kind",
          "revision": "example revision",
          "inventory": 1
      }

  JSON Parameters

    - project (integer) – Project(x-nullable=True)

    - initiator_type (string) – Initiator type(maxLength=50, minLength=1)

    - kind (string) – Kind(maxLength=50, minLength=1)

    - initiator (integer) – Initiator

    - raw_args (string) – Raw args(minLength=1)

    - revision (string) – Revision(maxLength=256, x-nullable=True)

    - stop_time (date-time) – Stop time(x-nullable=True)

    - start_time (date-time) – Start time

    - raw_stdout (string) – Raw stdout(readOnly=True)

    - raw_inventory (string) – Raw inventory(minLength=1)

    - executor (integer) – Executor(x-nullable=True)

    - status (string) – Status(enum=[‘DELAY’, ‘RUN’, ‘OK’, ‘ERROR’, ‘OFFLINE’, ‘INTERRUPTED’])

    - id (integer) – Id(readOnly=True)

    - execution_time (uptime) – Execution time

    - mode (string) – Mode(maxLength=256, minLength=1)

    - inventory (integer) – Inventory(x-nullable=True)

    - execute_args (string) – Execute args(readOnly=True)

    - options (string) – Options(readOnly=True)

param integer history_id(required)

  A unique integer value identifying instance of this history sublist.

param integer id(required)

  A unique integer value identifying this project.

`DELETE` `/project/{id}/history/{history_id}/`

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer history_id(required)

  A unique integer value identifying instance of this history sublist.

param integer id(required)

  A unique integer value identifying this project.

`POST` `/project/{id}/history/{history_id}/cancel/`

  Cencel working task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail"
      }

  JSON Parameters

    - detail (string) – Detail(minLength=1)

param integer history_id(required)

  A unique integer value identifying instance of this history sublist.

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    Empty Schema

`DELETE` `/project/{id}/history/{history_id}/clear/`

  Clear history output.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer history_id(required)

  A unique integer value identifying instance of this history sublist.

param integer id(required)

  A unique integer value identifying this project.

`GET` `/project/{id}/history/{history_id}/facts/`

  Get compilated history facts (only for execution ‘module’ with module ‘setup’).

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer history_id(required)

  A unique integer value identifying instance of this history sublist.

param integer id(required)

  A unique integer value identifying this project.

`GET` `/project/{id}/inventory/`

  Return all inventories.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Inventory Schema)

param integer id(required)

  A unique integer value identifying this project.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/inventory/`

  Create a new inventory.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    OneInventory Schema

`POST` `/project/{id}/inventory/import_inventory/`

  Create a new inventory.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "raw_data": "example raw_data",
          "inventory_id": 1
      }

  JSON Parameters

    - inventory_id (integer) – Inventory id(additionalProperties=OrderedDict([(‘redirect’, True)]), x-nullable=True)

    - raw_data (string) – Raw data(minLength=1)

    - name (string) – Name(minLength=1)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    InventoryImport Schema

`GET` `/project/{id}/inventory/{inventory_id}/`

  Return a inventory instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`PUT` `/project/{id}/inventory/{inventory_id}/`

  Update a inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    OneInventory Schema

`PATCH` `/project/{id}/inventory/{inventory_id}/`

  Update one or more fields on an existing inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    OneInventory Schema

`DELETE` `/project/{id}/inventory/{inventory_id}/`

  Remove an existing inventory.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`GET` `/project/{id}/inventory/{inventory_id}/all_groups/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "children": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/1/all_groups/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Group Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/project/{id}/inventory/{inventory_id}/all_groups/{all_groups_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param string all_groups_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`GET` `/project/{id}/inventory/{inventory_id}/all_hosts/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "HOST",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/1/all_hosts/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Host Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string type

  Instance type.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/project/{id}/inventory/{inventory_id}/all_hosts/{all_hosts_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param string all_hosts_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`POST` `/project/{id}/inventory/{inventory_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    Inventory Schema

`GET` `/project/{id}/inventory/{inventory_id}/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "children": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/1/group/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Group Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/inventory/{inventory_id}/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Contains groups(default=False)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    GroupCreateMaster Schema

`GET` `/project/{id}/inventory/{inventory_id}/group/{group_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`PUT` `/project/{id}/inventory/{inventory_id}/group/{group_id}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    OneGroup Schema

`PATCH` `/project/{id}/inventory/{inventory_id}/group/{group_id}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "children": true,
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    OneGroup Schema

`DELETE` `/project/{id}/inventory/{inventory_id}/group/{group_id}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`POST` `/project/{id}/inventory/{inventory_id}/group/{group_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "children": true,
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - id (integer) – Id(readOnly=True)

    - children (boolean) – Children(readOnly=True)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    Group Schema

`POST` `/project/{id}/inventory/{inventory_id}/group/{group_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    SetOwner Schema

`GET` `/project/{id}/inventory/{inventory_id}/group/{group_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/1/group/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/inventory/{inventory_id}/group/{group_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    InventoryVariable Schema

`GET` `/project/{id}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{id}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/project/{id}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/project/{id}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string group_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/project/{id}/inventory/{inventory_id}/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "type": "HOST",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/1/host/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Host Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string type

  Instance type.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string variables

  List of variables to filter. Comma separeted “key:value” list.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/inventory/{inventory_id}/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    OneHost Schema

`GET` `/project/{id}/inventory/{inventory_id}/host/{host_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`PUT` `/project/{id}/inventory/{inventory_id}/host/{host_id}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    OneHost Schema

`PATCH` `/project/{id}/inventory/{inventory_id}/host/{host_id}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=512, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – Id(readOnly=True)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    OneHost Schema

`DELETE` `/project/{id}/inventory/{inventory_id}/host/{host_id}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

`POST` `/project/{id}/inventory/{inventory_id}/host/{host_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "type": "HOST",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - type (string) – Type(enum=[‘HOST’, ‘RANGE’], default=HOST)

    - id (integer) – Id(readOnly=True)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    Host Schema

`POST` `/project/{id}/inventory/{inventory_id}/host/{host_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    SetOwner Schema

`GET` `/project/{id}/inventory/{inventory_id}/host/{host_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/1/host/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/inventory/{inventory_id}/host/{host_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    InventoryVariable Schema

`GET` `/project/{id}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{id}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/project/{id}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/project/{id}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string host_id(required)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`POST` `/project/{id}/inventory/{inventory_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    SetOwner Schema

`GET` `/project/{id}/inventory/{inventory_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "ansible_host",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/inventory/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (InventoryVariable Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/inventory/{inventory_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  > A unique integer value identifying instance of this inventories sublist.

  query schema data(required)

    InventoryVariable Schema

`GET` `/project/{id}/inventory/{inventory_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{id}/inventory/{inventory_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`PATCH` `/project/{id}/inventory/{inventory_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "ansible_host",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable)

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    InventoryVariable Schema

`DELETE` `/project/{id}/inventory/{inventory_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this project.

param integer inventory_id(required)

  A unique integer value identifying instance of this inventories sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/project/{id}/module/`

  Return all available modules of project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "path": "example path",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/module/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Module Schema)

param integer id(required)

  A unique integer value identifying this project.

query string path

  Full path to module.

query string path__not

  Full path to module.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/project/{id}/module/{module_id}/`

  Return a module details of project instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "data": {},
          "path": "example path",
          "id": 1
      }

  JSON Parameters

    - path (string) – Path(maxLength=1024, minLength=1)

    - name (string) – Name(readOnly=True)

    - id (integer) – Id(readOnly=True)

    - data (object) – (Data Schema)

param integer id(required)

  A unique integer value identifying this project.

param string module_id(required)

`GET` `/project/{id}/periodic_task/`

  Return all periodic tasks in project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "template_opt": "test_dynamic",
                  "template": 1,
                  "schedule": "test_dynamic",
                  "inventory": "test_dynamic",
                  "mode": "test_dynamic",
                  "enabled": true,
                  "name": "example name",
                  "id": 1,
                  "type": "CRONTAB",
                  "kind": "PLAYBOOK",
                  "save_result": true
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/periodic_task/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Periodictask Schema)

param integer id(required)

  A unique integer value identifying this project.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string mode

  Periodic task module or playbook name.

query string kind

  Kind of periodic task.

query string type

  Instance type.

query number template

  A unique integer id of template used in periodic task.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string name

  A name string value (or comma separated list) of instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/periodic_task/`

  Create a new periodic task.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "template_opt": "test_dynamic",
          "schedule": "test_dynamic",
          "inventory": "test_dynamic",
          "mode": "test_dynamic",
          "name": "example name",
          "type": "CRONTAB",
          "template": 1,
          "save_result": true,
          "notes": "example\ntext\narea\n",
          "id": 1,
          "enabled": true,
          "kind": "PLAYBOOK"
      }

  JSON Parameters

    - template_opt (dynamic) – Template opt

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK)

    - save_result (boolean) – Save result

    - inventory (dynamic) – Inventory

    - enabled (boolean) – Enabled

    - template (integer) – Template(x-nullable=True)

    - mode (dynamic) – Mode

    - type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB)

    - id (integer) – Id(readOnly=True)

    - notes (textarea) – Notes

    - schedule (dynamic) – Schedule

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    OnePeriodictask Schema

`GET` `/project/{id}/periodic_task/{periodic_task_id}/`

  Return a perodic task instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "template_opt": "test_dynamic",
          "schedule": "test_dynamic",
          "inventory": "test_dynamic",
          "mode": "test_dynamic",
          "name": "example name",
          "type": "CRONTAB",
          "template": 1,
          "save_result": true,
          "notes": "example\ntext\narea\n",
          "id": 1,
          "enabled": true,
          "kind": "PLAYBOOK"
      }

  JSON Parameters

    - template_opt (dynamic) – Template opt

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK)

    - save_result (boolean) – Save result

    - inventory (dynamic) – Inventory

    - enabled (boolean) – Enabled

    - template (integer) – Template(x-nullable=True)

    - mode (dynamic) – Mode

    - type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB)

    - id (integer) – Id(readOnly=True)

    - notes (textarea) – Notes

    - schedule (dynamic) – Schedule

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  A unique integer value identifying instance of this periodic_task sublist.

`PUT` `/project/{id}/periodic_task/{periodic_task_id}/`

  Update a periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "template_opt": "test_dynamic",
          "schedule": "test_dynamic",
          "inventory": "test_dynamic",
          "mode": "test_dynamic",
          "name": "example name",
          "type": "CRONTAB",
          "template": 1,
          "save_result": true,
          "notes": "example\ntext\narea\n",
          "id": 1,
          "enabled": true,
          "kind": "PLAYBOOK"
      }

  JSON Parameters

    - template_opt (dynamic) – Template opt

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK)

    - save_result (boolean) – Save result

    - inventory (dynamic) – Inventory

    - enabled (boolean) – Enabled

    - template (integer) – Template(x-nullable=True)

    - mode (dynamic) – Mode

    - type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB)

    - id (integer) – Id(readOnly=True)

    - notes (textarea) – Notes

    - schedule (dynamic) – Schedule

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  > A unique integer value identifying instance of this periodic_task sublist.

  query schema data(required)

    OnePeriodictask Schema

`PATCH` `/project/{id}/periodic_task/{periodic_task_id}/`

  Update one or more fields on an existing periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "template_opt": "test_dynamic",
          "schedule": "test_dynamic",
          "inventory": "test_dynamic",
          "mode": "test_dynamic",
          "name": "example name",
          "type": "CRONTAB",
          "template": 1,
          "save_result": true,
          "notes": "example\ntext\narea\n",
          "id": 1,
          "enabled": true,
          "kind": "PLAYBOOK"
      }

  JSON Parameters

    - template_opt (dynamic) – Template opt

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK)

    - save_result (boolean) – Save result

    - inventory (dynamic) – Inventory

    - enabled (boolean) – Enabled

    - template (integer) – Template(x-nullable=True)

    - mode (dynamic) – Mode

    - type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB)

    - id (integer) – Id(readOnly=True)

    - notes (textarea) – Notes

    - schedule (dynamic) – Schedule

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  > A unique integer value identifying instance of this periodic_task sublist.

  query schema data(required)

    OnePeriodictask Schema

`DELETE` `/project/{id}/periodic_task/{periodic_task_id}/`

  Remove an existing periodic task.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  A unique integer value identifying instance of this periodic_task sublist.

`POST` `/project/{id}/periodic_task/{periodic_task_id}/execute/`

  Ad-hoc execute periodic task.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "history_id": 1,
          "executor": 1
      }

  JSON Parameters

    - executor (integer) – Executor(x-nullable=True)

    - history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)]), x-nullable=True)

    - detail (string) – Detail(minLength=1)

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  > A unique integer value identifying instance of this periodic_task sublist.

  query schema data(required)

    Empty Schema

`GET` `/project/{id}/periodic_task/{periodic_task_id}/variables/`

  Return all variables of periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "example value",
                  "key": "example key",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/periodic_task/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (PeriodicTaskVariable Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  A unique integer value identifying instance of this periodic_task sublist.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/periodic_task/{periodic_task_id}/variables/`

  Create a new variable of periodic task.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "example value",
          "key": "example key",
          "id": 1
      }

  JSON Parameters

    - key (string) – Key(maxLength=512, minLength=1)

    - value (string) – Value(default=)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  > A unique integer value identifying instance of this periodic_task sublist.

  query schema data(required)

    PeriodicTaskVariable Schema

`GET` `/project/{id}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Return a variable of periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "example value",
          "key": "example key",
          "id": 1
      }

  JSON Parameters

    - key (string) – Key(maxLength=512, minLength=1)

    - value (string) – Value(default=)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  A unique integer value identifying instance of this periodic_task sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{id}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "example value",
          "key": "example key",
          "id": 1
      }

  JSON Parameters

    - key (string) – Key(maxLength=512, minLength=1)

    - value (string) – Value(default=)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  A unique integer value identifying instance of this periodic_task sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    PeriodicTaskVariable Schema

`PATCH` `/project/{id}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "example value",
          "key": "example key",
          "id": 1
      }

  JSON Parameters

    - key (string) – Key(maxLength=512, minLength=1)

    - value (string) – Value(default=)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  A unique integer value identifying instance of this periodic_task sublist.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    PeriodicTaskVariable Schema

`DELETE` `/project/{id}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this project.

param integer periodic_task_id(required)

  A unique integer value identifying instance of this periodic_task sublist.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/project/{id}/playbook/`

  Return all playbooks of project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "playbook": "example playbook",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/playbook/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Playbook Schema)

param integer id(required)

  A unique integer value identifying this project.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string playbook

  Playbook filename.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string playbook__not

  Playbook filename.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`GET` `/project/{id}/playbook/{playbook_id}/`

  Return a playbook of project instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "playbook": "example playbook",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=251, minLength=1)

    - playbook (string) – Playbook(readOnly=True, minLength=1)

    - id (integer) – Id(readOnly=True)

param integer id(required)

  A unique integer value identifying this project.

param integer playbook_id(required)

  A unique integer value identifying instance of this playbook sublist.

`POST` `/project/{id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    SetOwner Schema

`POST` `/project/{id}/sync/`

  Sync project with repository.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail"
      }

  JSON Parameters

    - detail (string) – Detail(minLength=1)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    Empty Schema

`GET` `/project/{id}/template/`

  Return all execute templates in project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "options_list": [
                      "array_example"
                  ],
                  "options": {},
                  "id": 1,
                  "name": "example name",
                  "kind": "Task",
                  "data": {}
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/template/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Template Schema)

param integer id(required)

  A unique integer value identifying this project.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string kind

  A kind of template.

query string inventory

  The inventory id or path in project.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/template/`

  Create a new execute template.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "options": {},
          "notes": "example\ntext\narea\n",
          "id": 1,
          "name": "example name",
          "options_list": [
              "array_example"
          ],
          "kind": "Task",
          "data": {}
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task)

    - options (object) – (Data Schema)

    - id (integer) – Id(readOnly=True)

    - options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True)

    - notes (textarea) – Notes

    - data (object) – (Data Schema)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    OneTemplate Schema

`GET` `/project/{id}/template/{template_id}/`

  Return a execute template instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "options": {},
          "notes": "example\ntext\narea\n",
          "id": 1,
          "name": "example name",
          "options_list": [
              "array_example"
          ],
          "kind": "Task",
          "data": {}
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task)

    - options (object) – (Data Schema)

    - id (integer) – Id(readOnly=True)

    - options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True)

    - notes (textarea) – Notes

    - data (object) – (Data Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer template_id(required)

  A unique integer value identifying instance of this template sublist.

`PUT` `/project/{id}/template/{template_id}/`

  Update a execute template.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "options": {},
          "notes": "example\ntext\narea\n",
          "id": 1,
          "name": "example name",
          "options_list": [
              "array_example"
          ],
          "kind": "Task",
          "data": {}
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task)

    - options (object) – (Data Schema)

    - id (integer) – Id(readOnly=True)

    - options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True)

    - notes (textarea) – Notes

    - data (object) – (Data Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer template_id(required)

  > A unique integer value identifying instance of this template sublist.

  query schema data(required)

    OneTemplate Schema

`PATCH` `/project/{id}/template/{template_id}/`

  Update one or more fields on an existing execute template.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "options": {},
          "notes": "example\ntext\narea\n",
          "id": 1,
          "name": "example name",
          "options_list": [
              "array_example"
          ],
          "kind": "Task",
          "data": {}
      }

  JSON Parameters

    - name (string) – Name(maxLength=512, minLength=1)

    - kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task)

    - options (object) – (Data Schema)

    - id (integer) – Id(readOnly=True)

    - options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True)

    - notes (textarea) – Notes

    - data (object) – (Data Schema)

param integer id(required)

  A unique integer value identifying this project.

param integer template_id(required)

  > A unique integer value identifying instance of this template sublist.

  query schema data(required)

    OneTemplate Schema

`DELETE` `/project/{id}/template/{template_id}/`

  Remove an existing execute template.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this project.

param integer template_id(required)

  A unique integer value identifying instance of this template sublist.

`POST` `/project/{id}/template/{template_id}/execute/`

  Execute template with option.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "history_id": 1,
          "executor": 1
      }

  JSON Parameters

    - executor (integer) – Executor(x-nullable=True)

    - history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)]), x-nullable=True)

    - detail (string) – Detail(minLength=1)

param integer id(required)

  A unique integer value identifying this project.

param integer template_id(required)

  > A unique integer value identifying instance of this template sublist.

  query schema data(required)

    TemplateExec Schema

`GET` `/project/{id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "value": "test_dynamic",
                  "key": "repo_type",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/project/1/variables/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (ProjectVariable Schema)

param integer id(required)

  A unique integer value identifying this project.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string key

  A key name string value (or comma separated list) of instance.

query string value

  A value of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/project/{id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "repo_type",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: repo_type, repo_sync_on_run, repo_sync_on_run_timeout, repo_branch, repo_password, repo_key, ci_template)

param integer id(required)

  > A unique integer value identifying this project.

  query schema data(required)

    ProjectVariable Schema

`GET` `/project/{id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "repo_type",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: repo_type, repo_sync_on_run, repo_sync_on_run_timeout, repo_branch, repo_password, repo_key, ci_template)

param integer id(required)

  A unique integer value identifying this project.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "repo_type",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: repo_type, repo_sync_on_run, repo_sync_on_run_timeout, repo_branch, repo_password, repo_key, ci_template)

param integer id(required)

  A unique integer value identifying this project.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    ProjectVariable Schema

`PATCH` `/project/{id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "value": "test_dynamic",
          "key": "repo_type",
          "id": 1
      }

  JSON Parameters

    - value (dynamic) – Value

    - id (integer) – Id(readOnly=True)

    - key (autocomplete) – Key(Example values: repo_type, repo_sync_on_run, repo_sync_on_run_timeout, repo_branch, repo_password, repo_key, ci_template)

param integer id(required)

  A unique integer value identifying this project.

param integer variables_id(required)

  > A unique integer value identifying instance of this variables sublist.

  query schema data(required)

    ProjectVariable Schema

`DELETE` `/project/{id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this project.

param integer variables_id(required)

  A unique integer value identifying instance of this variables sublist.

`GET` `/team/`

  Return all teams.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "name": "example name",
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/team/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (Team Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string name

  A name string value (or comma separated list) of instance.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string name__not

  A name string value (or comma separated list) of instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/team/`

  Create a new team.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=150, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – ID(readOnly=True)

  Query Parameters

    - data(required) (schema) – OneTeam Schema

`GET` `/team/{id}/`

  Return a team instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=150, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – ID(readOnly=True)

param integer id(required)

  A unique integer value identifying this user group.

`PUT` `/team/{id}/`

  Update a team.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=150, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – ID(readOnly=True)

param integer id(required)

  > A unique integer value identifying this user group.

  query schema data(required)

    OneTeam Schema

`PATCH` `/team/{id}/`

  Update one or more fields on an existing team.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "owner": {
              "username": "example username",
              "email": "example@mail.com",
              "is_active": true,
              "id": 1
          },
          "notes": "example\ntext\narea\n",
          "id": 1
      }

  JSON Parameters

    - owner (object) – (User Schema)

    - name (string) – Name(maxLength=150, minLength=1)

    - notes (textarea) – Notes

    - id (integer) – ID(readOnly=True)

param integer id(required)

  > A unique integer value identifying this user group.

  query schema data(required)

    OneTeam Schema

`DELETE` `/team/{id}/`

  Remove an existing team.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this user group.

`POST` `/team/{id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "id": 1
      }

  JSON Parameters

    - name (string) – Name(maxLength=150, minLength=1)

    - id (integer) – ID(readOnly=True)

param integer id(required)

  > A unique integer value identifying this user group.

  query schema data(required)

    Team Schema

`POST` `/team/{id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters

    - user_id (fk) – New owner(additionalProperties=OrderedDict([(‘model’, OrderedDict([(‘$ref’, ‘#/definitions/User’)])), (‘value_field’, ‘id’), (‘view_field’, ‘username’)]))

param integer id(required)

  > A unique integer value identifying this user group.

  query schema data(required)

    SetOwner Schema

`GET` `/team/{id}/user/`

  Return all users.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "username": "example username",
                  "email": "example@mail.com",
                  "is_active": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/team/1/user/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (User Schema)

param integer id(required)

  A unique integer value identifying this user group.

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string username

  A name string value (or comma separated list) of instance.

query string is_active

  Boolean value meaning status of user.

query string first_name

  Users first name.

query string last_name

  Users last name.

query string email

  Users e-mail value.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string username__not

  A name string value (or comma separated list) of instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/team/{id}/user/`

  Create a new user.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "is_staff": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "password": "example password",
          "id": 1,
          "password2": "example password2",
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - password (string) – Password(minLength=1)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - is_staff (boolean) – Is staff(default=False)

    - last_name (string) – Last name(maxLength=150)

    - password2 (string) – Repeat password(minLength=1)

param integer id(required)

  > A unique integer value identifying this user group.

  query schema data(required)

    CreateUser Schema

`GET` `/team/{id}/user/{user_id}/`

  Return a user instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "id": 1,
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - last_name (string) – Last name(maxLength=150)

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  A unique integer value identifying instance of this users sublist.

`PUT` `/team/{id}/user/{user_id}/`

  Update a user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "id": 1,
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - last_name (string) – Last name(maxLength=150)

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  > A unique integer value identifying instance of this users sublist.

  query schema data(required)

    OneUser Schema

`PATCH` `/team/{id}/user/{user_id}/`

  Update one or more fields on an existing user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "id": 1,
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - last_name (string) – Last name(maxLength=150)

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  > A unique integer value identifying instance of this users sublist.

  query schema data(required)

    OneUser Schema

`DELETE` `/team/{id}/user/{user_id}/`

  Remove an existing user.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  A unique integer value identifying instance of this users sublist.

`POST` `/team/{id}/user/{user_id}/change_password/`

  Create a new user.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "old_password": "example old_password",
          "password2": "example password2",
          "password": "example password"
      }

  JSON Parameters

    - old_password (string) – Old password(minLength=1)

    - password (string) – New password(minLength=1)

    - password2 (string) – Confirm new password(minLength=1)

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  > A unique integer value identifying instance of this users sublist.

  query schema data(required)

    ChangePassword Schema

`POST` `/team/{id}/user/{user_id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "email": "example@mail.com",
          "is_active": true,
          "id": 1
      }

  JSON Parameters

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - email (email) – Email(minLength=1)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  > A unique integer value identifying instance of this users sublist.

  query schema data(required)

    User Schema

`GET` `/team/{id}/user/{user_id}/settings/`

  from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES) Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "error": {
                  "active": true
              },
              "offline": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              },
              "delay": {
                  "active": true
              }
          },
          "autoupdateInterval": 15000,
          "widgetSettings": {
              "pmwProjectsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              }
          }
      }

  JSON Parameters

    - widgetSettings (object) – (WidgetSettings Schema)

    - chartLineSettings (object) – (ChartLineSettings Schema)

    - autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  A unique integer value identifying instance of this users sublist.

`POST` `/team/{id}/user/{user_id}/settings/`

  from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES) Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "error": {
                  "active": true
              },
              "offline": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              },
              "delay": {
                  "active": true
              }
          },
          "autoupdateInterval": 15000,
          "widgetSettings": {
              "pmwProjectsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              }
          }
      }

  JSON Parameters

    - widgetSettings (object) – (WidgetSettings Schema)

    - chartLineSettings (object) – (ChartLineSettings Schema)

    - autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  > A unique integer value identifying instance of this users sublist.

  query schema data(required)

    UserSettings Schema

`DELETE` `/team/{id}/user/{user_id}/settings/`

  from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES) Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this user group.

param integer user_id(required)

  A unique integer value identifying instance of this users sublist.

`GET` `/user/`

  Return all users.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "username": "example username",
                  "email": "example@mail.com",
                  "is_active": true,
                  "id": 1
              }
          ],
          "count": 2,
          "previous": null,
          "next": "http://localhost:8080/user/?limit=1&offset=1"
      }

  JSON Parameters

    - previous (uri) – (x-nullable=True)

    - next (uri) – (x-nullable=True)

    - count (integer) – None

    - results (array) – (User Schema)

query string id

  A unique integer value (or comma separated list) identifying this instance.

query string username

  A name string value (or comma separated list) of instance.

query string is_active

  Boolean value meaning status of user.

query string first_name

  Users first name.

query string last_name

  Users last name.

query string email

  Users e-mail value.

query string id__not

  A unique integer value (or comma separated list) identifying this instance.

query string username__not

  A name string value (or comma separated list) of instance.

query string ordering

  Which field to use when ordering the results.

query integer limit

  Number of results to return per page.

query integer offset

  The initial index from which to return the results.

`POST` `/user/`

  Create a new user.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "is_staff": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "password": "example password",
          "id": 1,
          "password2": "example password2",
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - password (string) – Password(minLength=1)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - is_staff (boolean) – Is staff(default=False)

    - last_name (string) – Last name(maxLength=150)

    - password2 (string) – Repeat password(minLength=1)

  Query Parameters

    - data(required) (schema) – CreateUser Schema

`GET` `/user/{id}/`

  Return a user instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "id": 1,
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - last_name (string) – Last name(maxLength=150)

param integer id(required)

  A unique integer value identifying this user.

`PUT` `/user/{id}/`

  Update a user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "id": 1,
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - last_name (string) – Last name(maxLength=150)

param integer id(required)

  > A unique integer value identifying this user.

  query schema data(required)

    OneUser Schema

`PATCH` `/user/{id}/`

  Update one or more fields on an existing user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name",
          "id": 1,
          "email": "example@mail.com",
          "is_active": true
      }

  JSON Parameters

    - email (email) – Email(minLength=1)

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - first_name (string) – First name(maxLength=30)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

    - last_name (string) – Last name(maxLength=150)

param integer id(required)

  > A unique integer value identifying this user.

  query schema data(required)

    OneUser Schema

`DELETE` `/user/{id}/`

  Remove an existing user.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this user.

`POST` `/user/{id}/change_password/`

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "old_password": "example old_password",
          "password2": "example password2",
          "password": "example password"
      }

  JSON Parameters

    - old_password (string) – Old password(minLength=1)

    - password (string) – New password(minLength=1)

    - password2 (string) – Confirm new password(minLength=1)

param integer id(required)

  > A unique integer value identifying this user.

  query schema data(required)

    ChangePassword Schema

`POST` `/user/{id}/copy/`

  Endpoint which copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "username": "example username",
          "email": "example@mail.com",
          "is_active": true,
          "id": 1
      }

  JSON Parameters

    - username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1)

    - email (email) – Email(minLength=1)

    - id (integer) – ID(readOnly=True)

    - is_active (boolean) – Is active(default=True)

param integer id(required)

  > A unique integer value identifying this user.

  query schema data(required)

    User Schema

`GET` `/user/{id}/settings/`

  Return user settings.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "error": {
                  "active": true
              },
              "offline": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              },
              "delay": {
                  "active": true
              }
          },
          "autoupdateInterval": 15000,
          "widgetSettings": {
              "pmwProjectsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              }
          }
      }

  JSON Parameters

    - widgetSettings (object) – (WidgetSettings Schema)

    - chartLineSettings (object) – (ChartLineSettings Schema)

    - autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param integer id(required)

  A unique integer value identifying this user.

`POST` `/user/{id}/settings/`

  Return user settings.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "error": {
                  "active": true
              },
              "offline": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              },
              "delay": {
                  "active": true
              }
          },
          "autoupdateInterval": 15000,
          "widgetSettings": {
              "pmwProjectsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "sort": 1,
                  "active": true
              }
          }
      }

  JSON Parameters

    - widgetSettings (object) – (WidgetSettings Schema)

    - chartLineSettings (object) – (ChartLineSettings Schema)

    - autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param integer id(required)

  > A unique integer value identifying this user.

  query schema data(required)

    UserSettings Schema

`DELETE` `/user/{id}/settings/`

  Return user settings.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer id(required)

  A unique integer value identifying this user.

### Schemas Description

#### ProjectTemplate Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer"
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "GIT",
>                 "TAR"
>             ]
>         }
>     }

#### Error Schema

>     {
>         "detail": {
>             "title": "Detail",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### OneProjectTemplate Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer"
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "description": {
>             "title": "Description",
>             "type": "string",
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "GIT",
>                 "TAR"
>             ]
>         },
>         "repository": {
>             "title": "Repository",
>             "type": "string",
>             "maxLength": 2048,
>             "minLength": 1
>         }
>     }

#### ProjectTemplateCreate Schema

>     {
>         "project_id": {
>             "title": "Project id",
>             "type": "integer",
>             "readOnly": true,
>             "additionalProperties": {
>                 "redirect": true
>             },
>             "x-nullable": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### Group Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "children": {
>             "title": "Children",
>             "type": "boolean",
>             "readOnly": true
>         }
>     }

#### User Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "username": {
>             "title": "Username",
>             "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>             "type": "string",
>             "pattern": "^[\\w.@+-]+$",
>             "maxLength": 150,
>             "minLength": 1
>         },
>         "is_active": {
>             "title": "Is active",
>             "type": "boolean",
>             "default": true
>         },
>         "email": {
>             "title": "Email",
>             "type": "string",
>             "format": "email",
>             "minLength": 1
>         }
>     }

#### GroupCreateMaster Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "children": {
>             "title": "Contains groups",
>             "type": "boolean",
>             "default": false
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

#### OneGroup Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "children": {
>             "title": "Children",
>             "type": "boolean",
>             "readOnly": true
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

#### SetOwner Schema

>     {
>         "user_id": {
>             "title": "New owner",
>             "type": "integer",
>             "format": "fk",
>             "additionalProperties": {
>                 "model": {
>                     "id": {
>                         "title": "ID",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "username": {
>                         "title": "Username",
>                         "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                         "type": "string",
>                         "pattern": "^[\\w.@+-]+$",
>                         "maxLength": 150,
>                         "minLength": 1
>                     },
>                     "is_active": {
>                         "title": "Is active",
>                         "type": "boolean",
>                         "default": true
>                     },
>                     "email": {
>                         "title": "Email",
>                         "type": "string",
>                         "format": "email",
>                         "minLength": 1
>                     }
>                 },
>                 "value_field": "id",
>                 "view_field": "username"
>             }
>         }
>     }

#### InventoryVariable Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "key": {
>             "title": "Key",
>             "type": "string",
>             "format": "autocomplete",
>             "enum": [
>                 "ansible_host",
>                 "ansible_port",
>                 "ansible_user",
>                 "ansible_connection",
>                 "ansible_ssh_pass",
>                 "ansible_ssh_private_key_file",
>                 "ansible_ssh_common_args",
>                 "ansible_sftp_extra_args",
>                 "ansible_scp_extra_args",
>                 "ansible_ssh_extra_args",
>                 "ansible_ssh_executable",
>                 "ansible_ssh_pipelining",
>                 "ansible_become",
>                 "ansible_become_method",
>                 "ansible_become_user",
>                 "ansible_become_pass",
>                 "ansible_become_exe",
>                 "ansible_become_flags",
>                 "ansible_shell_type",
>                 "ansible_python_interpreter",
>                 "ansible_ruby_interpreter",
>                 "ansible_perl_interpreter",
>                 "ansible_shell_executable"
>             ]
>         },
>         "value": {
>             "title": "Value",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "key",
>                 "types": {
>                     "ansible_become": "boolean",
>                     "ansible_become_pass": "password",
>                     "ansible_port": "integer",
>                     "ansible_ssh_pass": "password",
>                     "ansible_ssh_private_key_file": "secretfile"
>                 }
>             }
>         }
>     }

#### Host Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "HOST",
>                 "RANGE"
>             ],
>             "default": "HOST"
>         }
>     }

#### OneHost Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "HOST",
>                 "RANGE"
>             ],
>             "default": "HOST"
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

#### History Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "start_time": {
>             "title": "Start time",
>             "type": "string",
>             "format": "date-time"
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "initiator": {
>             "title": "Initiator",
>             "type": "integer"
>         },
>         "initiator_type": {
>             "title": "Initiator type",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "project": {
>             "title": "Project",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "kind": {
>             "title": "Kind",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         },
>         "options": {
>             "title": "Options",
>             "type": "string",
>             "readOnly": true
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "DELAY",
>                 "RUN",
>                 "OK",
>                 "ERROR",
>                 "OFFLINE",
>                 "INTERRUPTED"
>             ]
>         },
>         "stop_time": {
>             "title": "Stop time",
>             "type": "string",
>             "format": "date-time",
>             "x-nullable": true
>         }
>     }

#### OneHistory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "DELAY",
>                 "RUN",
>                 "OK",
>                 "ERROR",
>                 "OFFLINE",
>                 "INTERRUPTED"
>             ]
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "project": {
>             "title": "Project",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "revision": {
>             "title": "Revision",
>             "type": "string",
>             "maxLength": 256,
>             "x-nullable": true
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "kind": {
>             "title": "Kind",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         },
>         "execute_args": {
>             "title": "Execute args",
>             "type": "string",
>             "readOnly": true
>         },
>         "execution_time": {
>             "title": "Execution time",
>             "type": "integer",
>             "format": "uptime"
>         },
>         "start_time": {
>             "title": "Start time",
>             "type": "string",
>             "format": "date-time"
>         },
>         "stop_time": {
>             "title": "Stop time",
>             "type": "string",
>             "format": "date-time",
>             "x-nullable": true
>         },
>         "initiator": {
>             "title": "Initiator",
>             "type": "integer"
>         },
>         "initiator_type": {
>             "title": "Initiator type",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "options": {
>             "title": "Options",
>             "type": "string",
>             "readOnly": true
>         },
>         "raw_args": {
>             "title": "Raw args",
>             "type": "string",
>             "minLength": 1
>         },
>         "raw_stdout": {
>             "title": "Raw stdout",
>             "type": "string",
>             "readOnly": true
>         },
>         "raw_inventory": {
>             "title": "Raw inventory",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### Empty Schema

>     {}

#### ActionResponse Schema

>     {
>         "detail": {
>             "title": "Detail",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### Data Schema

>     {}

#### Hook Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "HTTP",
>                 "SCRIPT"
>             ]
>         },
>         "when": {
>             "title": "When",
>             "type": "string",
>             "enum": [
>                 "on_execution",
>                 "after_execution",
>                 "on_user_add",
>                 "on_user_upd",
>                 "on_user_del",
>                 "on_object_add",
>                 "on_object_upd",
>                 "on_object_del"
>             ]
>         },
>         "enable": {
>             "title": "Enable",
>             "type": "boolean"
>         },
>         "recipients": {
>             "title": "Recipients",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### Inventory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         }
>     }

#### OneInventory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

#### InventoryImport Schema

>     {
>         "inventory_id": {
>             "title": "Inventory id",
>             "type": "integer",
>             "additionalProperties": {
>                 "redirect": true
>             },
>             "x-nullable": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "minLength": 1
>         },
>         "raw_data": {
>             "title": "Raw data",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### Project Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "readOnly": true,
>             "minLength": 1
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "NEW",
>                 "ERROR",
>                 "OK",
>                 "WAIT_SYNC",
>                 "SYNC"
>             ],
>             "readOnly": true
>         }
>     }

#### ProjectCreateMaster Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "readOnly": true,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Repo type",
>             "type": "string",
>             "enum": [
>                 "MANUAL",
>                 "GIT",
>                 "TAR"
>             ],
>             "default": "MANUAL"
>         },
>         "repository": {
>             "title": "Repo url",
>             "type": "string",
>             "default": "MANUAL",
>             "minLength": 1
>         },
>         "repo_auth": {
>             "title": "Repo auth type",
>             "type": "string",
>             "format": "dynamic",
>             "default": "NONE",
>             "additionalProperties": {
>                 "choices": {
>                     "GIT": [
>                         "NONE",
>                         "KEY",
>                         "PASSWORD"
>                     ]
>                 },
>                 "field": "type",
>                 "types": {
>                     "GIT": "string",
>                     "MANUAL": "hidden",
>                     "TAR": "hidden"
>                 }
>             }
>         },
>         "auth_data": {
>             "title": "Repo auth data",
>             "type": "string",
>             "format": "dynamic",
>             "default": "",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "repo_auth",
>                 "types": {
>                     "KEY": "secretfile",
>                     "NONE": "hidden",
>                     "PASSWORD": "password"
>                 }
>             }
>         },
>         "branch": {
>             "title": "Branch for GIT(branch/tag/SHA) or TAR(subdir)",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "type",
>                 "types": {
>                     "GIT": "string",
>                     "MANUAL": "hidden",
>                     "TAR": "string"
>                 }
>             },
>             "x-nullable": true
>         }
>     }

#### OneProject Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "repository": {
>             "title": "Repository",
>             "type": "string",
>             "default": "MANUAL",
>             "minLength": 1
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "NEW",
>                 "ERROR",
>                 "OK",
>                 "WAIT_SYNC",
>                 "SYNC"
>             ],
>             "readOnly": true
>         },
>         "revision": {
>             "title": "Revision",
>             "type": "string",
>             "readOnly": true
>         },
>         "branch": {
>             "title": "Branch",
>             "type": "string",
>             "readOnly": true
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "readme_content": {
>             "title": "Information",
>             "type": "string",
>             "format": "html",
>             "readOnly": true
>         },
>         "execute_view_data": {}
>     }

#### AnsibleModule Schema

>     {
>         "module": {
>             "title": "Module",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "path": {
>                         "title": "Path",
>                         "type": "string",
>                         "maxLength": 1024,
>                         "minLength": 1
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "readOnly": true
>                     }
>                 },
>                 "value_field": "name",
>                 "view_field": "path"
>             }
>         },
>         "args": {
>             "title": "Args",
>             "description": "module arguments",
>             "type": "string"
>         },
>         "background": {
>             "title": "Background",
>             "description": "run asynchronously, failing after X seconds (default=N/A)",
>             "type": "integer"
>         },
>         "become": {
>             "title": "Become",
>             "description": "run operations with become (does not imply password prompting)",
>             "type": "boolean",
>             "default": false
>         },
>         "become_method": {
>             "title": "Become method",
>             "description": "privilege escalation method to use (default=sudo), valid choices: [ sudo | su | pbrun | pfexec | doas | dzdo | ksu | runas | pmrun | enable | machinectl ]",
>             "type": "string"
>         },
>         "become_user": {
>             "title": "Become user",
>             "description": "run operations as this user (default=root)",
>             "type": "string"
>         },
>         "check": {
>             "title": "Check",
>             "description": "don't make any changes; instead, try to predict some of the changes that may occur",
>             "type": "boolean",
>             "default": false
>         },
>         "connection": {
>             "title": "Connection",
>             "description": "connection type to use (default=smart)",
>             "type": "string"
>         },
>         "diff": {
>             "title": "Diff",
>             "description": "when changing (small) files and templates, show the differences in those files; works great with --check",
>             "type": "boolean",
>             "default": false
>         },
>         "extra_vars": {
>             "title": "Extra vars",
>             "description": "set additional variables as key=value or YAML/JSON, if filename prepend with @",
>             "type": "string"
>         },
>         "forks": {
>             "title": "Forks",
>             "description": "specify number of parallel processes to use (default=5)",
>             "type": "integer"
>         },
>         "inventory": {
>             "title": "Inventory",
>             "description": "specify inventory host path or comma separated host list. --inventory-file is deprecated",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "maxLength": 512,
>                         "minLength": 1
>                     }
>                 },
>                 "value_field": "id",
>                 "view_field": "name"
>             }
>         },
>         "key_file": {
>             "title": "Key file",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "limit": {
>             "title": "Limit",
>             "description": "further limit selected hosts to an additional pattern",
>             "type": "string"
>         },
>         "list_hosts": {
>             "title": "List hosts",
>             "description": "outputs a list of matching hosts; does not execute anything else",
>             "type": "boolean",
>             "default": false
>         },
>         "module_path": {
>             "title": "Module path",
>             "description": "prepend colon-separated path(s) to module library (default=[u'/home/grey/.ansible/plugins/modules', u'/usr/share/ansible/plugins/modules'])",
>             "type": "string"
>         },
>         "one_line": {
>             "title": "One line",
>             "description": "condense output",
>             "type": "boolean",
>             "default": false
>         },
>         "playbook_dir": {
>             "title": "Playbook dir",
>             "description": "Since this tool does not use playbooks, use this as a subsitute playbook directory.This sets the relative path for many features including roles/ group_vars/ etc.",
>             "type": "string"
>         },
>         "poll": {
>             "title": "Poll",
>             "description": "set the poll interval if using -B (default=15)",
>             "type": "integer"
>         },
>         "private_key": {
>             "title": "Private key",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "scp_extra_args": {
>             "title": "Scp extra args",
>             "description": "specify extra arguments to pass to scp only (e.g. -l)",
>             "type": "string"
>         },
>         "sftp_extra_args": {
>             "title": "Sftp extra args",
>             "description": "specify extra arguments to pass to sftp only (e.g. -f, -l)",
>             "type": "string"
>         },
>         "ssh_common_args": {
>             "title": "Ssh common args",
>             "description": "specify common arguments to pass to sftp/scp/ssh (e.g. ProxyCommand)",
>             "type": "string"
>         },
>         "ssh_extra_args": {
>             "title": "Ssh extra args",
>             "description": "specify extra arguments to pass to ssh only (e.g. -R)",
>             "type": "string"
>         },
>         "su": {
>             "title": "Su",
>             "description": "run operations with su (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "su_user": {
>             "title": "Su user",
>             "description": "run operations with su as this user (default=None) (deprecated, use become)",
>             "type": "string"
>         },
>         "sudo": {
>             "title": "Sudo",
>             "description": "run operations with sudo (nopasswd) (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "sudo_user": {
>             "title": "Sudo user",
>             "description": "desired sudo user (default=root) (deprecated, use become)",
>             "type": "string"
>         },
>         "syntax_check": {
>             "title": "Syntax check",
>             "description": "perform a syntax check on the playbook, but do not execute it",
>             "type": "boolean",
>             "default": false
>         },
>         "timeout": {
>             "title": "Timeout",
>             "description": "override the connection timeout in seconds (default=10)",
>             "type": "integer"
>         },
>         "tree": {
>             "title": "Tree",
>             "description": "log output to this directory",
>             "type": "string"
>         },
>         "user": {
>             "title": "User",
>             "description": "connect as this user (default=None)",
>             "type": "string"
>         },
>         "vault_id": {
>             "title": "Vault id",
>             "description": "the vault identity to use",
>             "type": "string"
>         },
>         "vault_password_file": {
>             "title": "Vault password file",
>             "description": "vault password file",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "verbose": {
>             "title": "Verbose",
>             "description": "verbose mode (-vvv for more, -vvvv to enable connection debugging)",
>             "type": "integer",
>             "default": 0,
>             "maximum": 4
>         },
>         "group": {
>             "title": "Group",
>             "type": "string",
>             "default": "all"
>         }
>     }

#### ExecuteResponse Schema

>     {
>         "detail": {
>             "title": "Detail",
>             "type": "string",
>             "minLength": 1
>         },
>         "history_id": {
>             "title": "History id",
>             "type": "integer",
>             "additionalProperties": {
>                 "redirect": true
>             },
>             "x-nullable": true
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer",
>             "x-nullable": true
>         }
>     }

#### AnsiblePlaybook Schema

>     {
>         "playbook": {
>             "title": "Playbook",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "maxLength": 251,
>                         "minLength": 1
>                     },
>                     "playbook": {
>                         "title": "Playbook",
>                         "type": "string",
>                         "maxLength": 256,
>                         "minLength": 1
>                     }
>                 },
>                 "value_field": "playbook",
>                 "view_field": "name"
>             }
>         },
>         "become": {
>             "title": "Become",
>             "description": "run operations with become (does not imply password prompting)",
>             "type": "boolean",
>             "default": false
>         },
>         "become_method": {
>             "title": "Become method",
>             "description": "privilege escalation method to use (default=sudo), valid choices: [ sudo | su | pbrun | pfexec | doas | dzdo | ksu | runas | pmrun | enable | machinectl ]",
>             "type": "string"
>         },
>         "become_user": {
>             "title": "Become user",
>             "description": "run operations as this user (default=root)",
>             "type": "string"
>         },
>         "check": {
>             "title": "Check",
>             "description": "don't make any changes; instead, try to predict some of the changes that may occur",
>             "type": "boolean",
>             "default": false
>         },
>         "connection": {
>             "title": "Connection",
>             "description": "connection type to use (default=smart)",
>             "type": "string"
>         },
>         "diff": {
>             "title": "Diff",
>             "description": "when changing (small) files and templates, show the differences in those files; works great with --check",
>             "type": "boolean",
>             "default": false
>         },
>         "extra_vars": {
>             "title": "Extra vars",
>             "description": "set additional variables as key=value or YAML/JSON, if filename prepend with @",
>             "type": "string"
>         },
>         "flush_cache": {
>             "title": "Flush cache",
>             "description": "clear the fact cache for every host in inventory",
>             "type": "boolean",
>             "default": false
>         },
>         "force_handlers": {
>             "title": "Force handlers",
>             "description": "run handlers even if a task fails",
>             "type": "boolean",
>             "default": false
>         },
>         "forks": {
>             "title": "Forks",
>             "description": "specify number of parallel processes to use (default=5)",
>             "type": "integer"
>         },
>         "inventory": {
>             "title": "Inventory",
>             "description": "specify inventory host path or comma separated host list. --inventory-file is deprecated",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "maxLength": 512,
>                         "minLength": 1
>                     }
>                 },
>                 "value_field": "id",
>                 "view_field": "name"
>             }
>         },
>         "key_file": {
>             "title": "Key file",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "limit": {
>             "title": "Limit",
>             "description": "further limit selected hosts to an additional pattern",
>             "type": "string"
>         },
>         "list_hosts": {
>             "title": "List hosts",
>             "description": "outputs a list of matching hosts; does not execute anything else",
>             "type": "boolean",
>             "default": false
>         },
>         "list_tags": {
>             "title": "List tags",
>             "description": "list all available tags",
>             "type": "boolean",
>             "default": false
>         },
>         "list_tasks": {
>             "title": "List tasks",
>             "description": "list all tasks that would be executed",
>             "type": "boolean",
>             "default": false
>         },
>         "module_path": {
>             "title": "Module path",
>             "description": "prepend colon-separated path(s) to module library (default=[u'/home/grey/.ansible/plugins/modules', u'/usr/share/ansible/plugins/modules'])",
>             "type": "string"
>         },
>         "private_key": {
>             "title": "Private key",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "scp_extra_args": {
>             "title": "Scp extra args",
>             "description": "specify extra arguments to pass to scp only (e.g. -l)",
>             "type": "string"
>         },
>         "sftp_extra_args": {
>             "title": "Sftp extra args",
>             "description": "specify extra arguments to pass to sftp only (e.g. -f, -l)",
>             "type": "string"
>         },
>         "skip_tags": {
>             "title": "Skip tags",
>             "description": "only run plays and tasks whose tags do not match these values",
>             "type": "string"
>         },
>         "ssh_common_args": {
>             "title": "Ssh common args",
>             "description": "specify common arguments to pass to sftp/scp/ssh (e.g. ProxyCommand)",
>             "type": "string"
>         },
>         "ssh_extra_args": {
>             "title": "Ssh extra args",
>             "description": "specify extra arguments to pass to ssh only (e.g. -R)",
>             "type": "string"
>         },
>         "start_at_task": {
>             "title": "Start at task",
>             "description": "start the playbook at the task matching this name",
>             "type": "string"
>         },
>         "step": {
>             "title": "Step",
>             "description": "one-step-at-a-time: confirm each task before running",
>             "type": "boolean",
>             "default": false
>         },
>         "su": {
>             "title": "Su",
>             "description": "run operations with su (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "su_user": {
>             "title": "Su user",
>             "description": "run operations with su as this user (default=None) (deprecated, use become)",
>             "type": "string"
>         },
>         "sudo": {
>             "title": "Sudo",
>             "description": "run operations with sudo (nopasswd) (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "sudo_user": {
>             "title": "Sudo user",
>             "description": "desired sudo user (default=root) (deprecated, use become)",
>             "type": "string"
>         },
>         "syntax_check": {
>             "title": "Syntax check",
>             "description": "perform a syntax check on the playbook, but do not execute it",
>             "type": "boolean",
>             "default": false
>         },
>         "tags": {
>             "title": "Tags",
>             "description": "only run plays and tasks tagged with these values",
>             "type": "string"
>         },
>         "timeout": {
>             "title": "Timeout",
>             "description": "override the connection timeout in seconds (default=10)",
>             "type": "integer"
>         },
>         "user": {
>             "title": "User",
>             "description": "connect as this user (default=None)",
>             "type": "string"
>         },
>         "vault_id": {
>             "title": "Vault id",
>             "description": "the vault identity to use",
>             "type": "string"
>         },
>         "vault_password_file": {
>             "title": "Vault password file",
>             "description": "vault password file",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "verbose": {
>             "title": "Verbose",
>             "description": "verbose mode (-vvv for more, -vvvv to enable connection debugging)",
>             "type": "integer",
>             "default": 0,
>             "maximum": 4
>         }
>     }

#### ProjectHistory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "start_time": {
>             "title": "Start time",
>             "type": "string",
>             "format": "date-time"
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "initiator": {
>             "title": "Initiator",
>             "type": "integer"
>         },
>         "initiator_type": {
>             "title": "Initiator type",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "revision": {
>             "title": "Revision",
>             "type": "string",
>             "maxLength": 256,
>             "x-nullable": true
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "kind": {
>             "title": "Kind",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         },
>         "options": {
>             "title": "Options",
>             "type": "string",
>             "readOnly": true
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "DELAY",
>                 "RUN",
>                 "OK",
>                 "ERROR",
>                 "OFFLINE",
>                 "INTERRUPTED"
>             ]
>         },
>         "stop_time": {
>             "title": "Stop time",
>             "type": "string",
>             "format": "date-time",
>             "x-nullable": true
>         }
>     }

#### Module Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "path": {
>             "title": "Path",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "readOnly": true
>         }
>     }

#### OneModule Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "path": {
>             "title": "Path",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "readOnly": true
>         },
>         "data": {}
>     }

#### Periodictask Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "kind": {
>             "title": "Task type",
>             "type": "string",
>             "enum": [
>                 "PLAYBOOK",
>                 "MODULE",
>                 "TEMPLATE"
>             ],
>             "default": "PLAYBOOK"
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "fk_autocomplete",
>                     "PLAYBOOK": "fk_autocomplete",
>                     "TEMPLATE": "hidden"
>                 }
>             }
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "fk_autocomplete",
>                     "PLAYBOOK": "fk_autocomplete",
>                     "TEMPLATE": "hidden"
>                 }
>             }
>         },
>         "save_result": {
>             "title": "Save result",
>             "type": "boolean"
>         },
>         "template": {
>             "title": "Template",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "template_opt": {
>             "title": "Template opt",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "hidden",
>                     "PLAYBOOK": "hidden",
>                     "TEMPLATE": "autocomplete"
>                 }
>             }
>         },
>         "enabled": {
>             "title": "Enabled",
>             "type": "boolean"
>         },
>         "type": {
>             "title": "Interval type",
>             "type": "string",
>             "enum": [
>                 "CRONTAB",
>                 "INTERVAL"
>             ],
>             "default": "CRONTAB"
>         },
>         "schedule": {
>             "title": "Schedule",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "type",
>                 "types": {
>                     "CRONTAB": "crontab",
>                     "INTERVAL": "integer"
>                 }
>             }
>         }
>     }

#### OnePeriodictask Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "kind": {
>             "title": "Task type",
>             "type": "string",
>             "enum": [
>                 "PLAYBOOK",
>                 "MODULE",
>                 "TEMPLATE"
>             ],
>             "default": "PLAYBOOK"
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "fk_autocomplete",
>                     "PLAYBOOK": "fk_autocomplete",
>                     "TEMPLATE": "hidden"
>                 }
>             }
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "fk_autocomplete",
>                     "PLAYBOOK": "fk_autocomplete",
>                     "TEMPLATE": "hidden"
>                 }
>             }
>         },
>         "save_result": {
>             "title": "Save result",
>             "type": "boolean"
>         },
>         "template": {
>             "title": "Template",
>             "type": "integer",
>             "x-nullable": true
>         },
>         "template_opt": {
>             "title": "Template opt",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "hidden",
>                     "PLAYBOOK": "hidden",
>                     "TEMPLATE": "autocomplete"
>                 }
>             }
>         },
>         "enabled": {
>             "title": "Enabled",
>             "type": "boolean"
>         },
>         "type": {
>             "title": "Interval type",
>             "type": "string",
>             "enum": [
>                 "CRONTAB",
>                 "INTERVAL"
>             ],
>             "default": "CRONTAB"
>         },
>         "schedule": {
>             "title": "Schedule",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {},
>                 "field": "type",
>                 "types": {
>                     "CRONTAB": "crontab",
>                     "INTERVAL": "integer"
>                 }
>             }
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         }
>     }

#### PeriodicTaskVariable Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "key": {
>             "title": "Key",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "value": {
>             "title": "Value",
>             "type": "string",
>             "default": ""
>         }
>     }

#### Playbook Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 251,
>             "minLength": 1
>         },
>         "playbook": {
>             "title": "Playbook",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         }
>     }

#### OnePlaybook Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 251,
>             "minLength": 1
>         },
>         "playbook": {
>             "title": "Playbook",
>             "type": "string",
>             "readOnly": true,
>             "minLength": 1
>         }
>     }

#### Template Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "kind": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "Task",
>                 "Module"
>             ],
>             "default": "Task"
>         },
>         "data": {},
>         "options": {},
>         "options_list": {
>             "type": "array",
>             "items": {
>                 "type": "string"
>             },
>             "readOnly": true
>         }
>     }

#### OneTemplate Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "kind": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "Task",
>                 "Module"
>             ],
>             "default": "Task"
>         },
>         "data": {},
>         "options": {},
>         "options_list": {
>             "type": "array",
>             "items": {
>                 "type": "string"
>             },
>             "readOnly": true
>         }
>     }

#### TemplateExec Schema

>     {
>         "option": {
>             "title": "Option",
>             "description": "Option name from template options.",
>             "type": "string",
>             "minLength": 0
>         }
>     }

#### ProjectVariable Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "key": {
>             "title": "Key",
>             "type": "string",
>             "format": "autocomplete",
>             "enum": [
>                 "repo_type",
>                 "repo_sync_on_run",
>                 "repo_sync_on_run_timeout",
>                 "repo_branch",
>                 "repo_password",
>                 "repo_key",
>                 "ci_template"
>             ]
>         },
>         "value": {
>             "title": "Value",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "choices": {
>                     "repo_sync_on_run": [
>                         true,
>                         false
>                     ],
>                     "repo_type": [
>                         "MANUAL",
>                         "GIT",
>                         "TAR"
>                     ]
>                 },
>                 "field": "key",
>                 "types": {
>                     "ci_template": "fk",
>                     "repo_key": "secretfile",
>                     "repo_password": "password",
>                     "repo_sync_on_run_timeout": "uptime"
>                 }
>             }
>         }
>     }

#### Team Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 150,
>             "minLength": 1
>         }
>     }

#### OneTeam Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 150,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

#### CreateUser Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "username": {
>             "title": "Username",
>             "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>             "type": "string",
>             "pattern": "^[\\w.@+-]+$",
>             "maxLength": 150,
>             "minLength": 1
>         },
>         "is_active": {
>             "title": "Is active",
>             "type": "boolean",
>             "default": true
>         },
>         "is_staff": {
>             "title": "Is staff",
>             "type": "boolean",
>             "default": false
>         },
>         "first_name": {
>             "title": "First name",
>             "type": "string",
>             "maxLength": 30
>         },
>         "last_name": {
>             "title": "Last name",
>             "type": "string",
>             "maxLength": 150
>         },
>         "email": {
>             "title": "Email",
>             "type": "string",
>             "format": "email",
>             "minLength": 1
>         },
>         "password": {
>             "title": "Password",
>             "type": "string",
>             "minLength": 1
>         },
>         "password2": {
>             "title": "Repeat password",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### OneUser Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "username": {
>             "title": "Username",
>             "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>             "type": "string",
>             "pattern": "^[\\w.@+-]+$",
>             "maxLength": 150,
>             "minLength": 1
>         },
>         "is_active": {
>             "title": "Is active",
>             "type": "boolean",
>             "default": true
>         },
>         "first_name": {
>             "title": "First name",
>             "type": "string",
>             "maxLength": 30
>         },
>         "last_name": {
>             "title": "Last name",
>             "type": "string",
>             "maxLength": 150
>         },
>         "email": {
>             "title": "Email",
>             "type": "string",
>             "format": "email",
>             "minLength": 1
>         }
>     }

#### ChangePassword Schema

>     {
>         "old_password": {
>             "title": "Old password",
>             "type": "string",
>             "minLength": 1
>         },
>         "password": {
>             "title": "New password",
>             "type": "string",
>             "minLength": 1
>         },
>         "password2": {
>             "title": "Confirm new password",
>             "type": "string",
>             "minLength": 1
>         }
>     }

#### ChartLineSetting Schema

>     {
>         "active": {
>             "title": "Active",
>             "type": "boolean",
>             "default": true
>         }
>     }

#### ChartLineSettings Schema

>     {
>         "all_tasks": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "delay": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "ok": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "error": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "interrupted": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "offline": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         }
>     }

#### CounterWidgetSetting Schema

>     {
>         "active": {
>             "title": "Active",
>             "type": "boolean",
>             "default": true
>         },
>         "collapse": {
>             "title": "Collapse",
>             "type": "boolean",
>             "readOnly": true,
>             "default": false
>         },
>         "sort": {
>             "title": "Sort",
>             "type": "integer",
>             "default": 0
>         }
>     }

#### WidgetSetting Schema

>     {
>         "active": {
>             "title": "Active",
>             "type": "boolean",
>             "default": true
>         },
>         "collapse": {
>             "title": "Collapse",
>             "type": "boolean",
>             "default": false
>         },
>         "sort": {
>             "title": "Sort",
>             "type": "integer",
>             "default": 0
>         }
>     }

#### WidgetSettings Schema

>     {
>         "pmwUsersCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwProjectsCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwTemplatesCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwInventoriesCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwGroupsCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwHostsCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwChartWidget": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         }
>     }

#### UserSettings Schema

>     {
>         "autoupdateInterval": {
>             "title": "Autoupdateinterval",
>             "type": "integer",
>             "default": 15000
>         },
>         "chartLineSettings": {
>             "all_tasks": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "delay": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "ok": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "error": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "interrupted": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "offline": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             }
>         },
>         "widgetSettings": {
>             "pmwUsersCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwProjectsCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwTemplatesCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwInventoriesCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwGroupsCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwHostsCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwChartWidget": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             }
>         }
>     }